@@ -21,14 +21,14 @@ test_that("adding and removing files", {
   repo <- git_init(tempfile("gert-tests-commit"))
   on.exit(unlink(repo, recursive = TRUE))
 
-  expect_equal(nrow(git_ls(repo)), 0)
+  expect_equal(nrow(git_ls(repo = repo)), 0)
   write.csv(iris, file.path(repo, 'iris.csv'))
   write.csv(cars, file.path(repo, 'cars.csv'))
   git_add(c('cars.csv', 'iris.csv'), repo = repo)
-  expect_equal(nrow(git_ls(repo)), 2)
-  expect_equal(git_ls(repo)$path, c('cars.csv', 'iris.csv'))
+  expect_equal(nrow(git_ls(repo = repo)), 2)
+  expect_equal(git_ls(repo = repo)$path, c('cars.csv', 'iris.csv'))
   git_rm(c('cars.csv', 'iris.csv'), repo = repo)
-  expect_equal(nrow(git_ls(repo)), 0)
+  expect_equal(nrow(git_ls(repo = repo)), 0)
   remotes <- git_remote_list(repo)
   expect_equal(nrow(remotes), 0)
 })
@@ -38,7 +38,7 @@ test_that("creating a commit", {
   on.exit(unlink(repo, recursive = TRUE))
   configure_local_user(repo)
 
-  expect_equal(nrow(git_ls(repo)), 0)
+  expect_equal(nrow(git_ls(repo = repo)), 0)
   dir.create(file.path(repo, 'src'))
   write.csv(cars, file.path(repo, 'src', 'cars.csv'))
   git_add('src/cars.csv', repo = repo)
@@ -61,6 +61,19 @@ test_that("creating a commit", {
   expect_equal(log$time[1], timestamp)
 })
 
+test_that("Passing ref into git_ls gives correct info", {
+  t <- tempfile()
+  dir.create(t)
+  writeLines(c("# Example", "", "example repo"), file.path(t, "README.md"))
+  git_init(t)
+  git_add(".", repo = t)
+  user <- "author <author@example.com>"
+  sha <- git_commit("initial", author = user, committer = user, repo = t)
+  without_ref <- git_ls(repo = t)
+  with_ref <- git_ls(repo = t, ref = "HEAD")
+  expect_equal(with_ref, without_ref)
+})
+
 test_that("creating a commit in another directory without author works", {
   path <- tempfile("gert-tests-commit")
   on.exit(unlink(path, recursive = TRUE))
@@ -87,13 +100,14 @@ test_that("status reports a conflicted file", {
   writeLines("cranky-crab-legs", foo_path)
   git_add("foo.txt", repo = repo)
   base <- git_commit("Add a file", repo = repo)
+  main <- git_branch(repo = repo)
 
   git_branch_create("my-branch", repo = repo)
   writeLines("cranky-CRAB-LEGS", foo_path)
   git_add("foo.txt", repo = repo)
   git_commit("Uppercase last 2 words", repo = repo)
 
-  git_branch_checkout("master", repo = repo)
+  git_branch_checkout(main, repo = repo)
   expect_equal(git_merge_analysis("my-branch", repo = repo), "fastforward")
 
   writeLines("CRANKY-CRAB-legs", foo_path)
